==> openid_selector-6.x-1.0.tar.gz: openid_selector/openid_selector.js <==
// $Id: openid_selector.js,v 1.1 2010/10/06 20:21:46 agerasika Exp $

var openid_selector = {
  img_path : null,
  form_id : null,
  init : function() {
    $('#edit-openid-identifier').val('')[0].id = 'old-edit-openid-identifier';
    $('#edit-openid-identifier-wrapper')
        .wrapInner('<div style="display: none;"/>')
        .prepend(
            '<div id="edit-openid-identifier"/> \
             <form action="javascript:openid_selector.inner_submit()" \
                id="openid_form" style="display: inline;"> \
                <div id="openid_choice"> \
                   <p>Click on your account provider:</p> \
                   <div id="openid_btns"/> \
                   <div id="openid_input_area" class="form-item"/> \
               </div> \
             </form>');
    openid.init("openid_identifier");
    $('#' + this.form_id).submit(this.outer_submit);
  },
  outer_submit : function() {
    openid.submit();
    if ($('#edit-openid-identifier-wrapper:visible').length > 0) {
      var val = $('#openid_identifier').val();
      $('#old-edit-openid-identifier').val(val);
    }
  },
  inner_submit : function() {
    this.outer_submit();
    $('#' + this.form_id).submit();
  }
};

// ui customization, overrides openid methods
openid.useInputBox = function(provider) {
  var is_block = openid_selector.form_id == 'user-login-form';
  var is_openid = provider['name'] == 'OpenID';
  $('#openid_input_area')
      .empty()
      .append(
          '<label for="openid_username">Log in using '
              + provider['name']
              + ':</label> \
           <input id="openid_username" type="text" style="'
              + (is_openid ? 'background:#FFF url('
                  + this.img_path
                  + 'openid-inputicon.gif) no-repeat scroll 0 50%; padding-left:18px;'
                  : '') + '" name="openid_username" value="'
              + (is_openid ? 'http://' : '') + '" maxlength="255" size="'
              + (is_block ? 15 : 58)
              + '" class="form-text"/> \
           <div class="description">'
              + provider['label'] + '</div>');
  $('#openid_username').focus();
}
providers_large.openid.label = '<a href="http://openid.net/">What is OpenID?</a>';
providers.openid.label = providers_large.openid.label;

openid.old_getBoxHTML = openid.getBoxHTML;
openid.getBoxHTML = function(provider, box_size, image_ext) {
  if (openid_selector.form_id == 'user-login-form' && box_size == 'large') {
    box_size = 'small';
    image_ext = '.ico';
  }
  if (image_ext == '.ico') {
    image_ext = '.ico.gif'
    var old_img_path = this.img_path;
    this.img_path = openid_selector.img_path;
    var result = this.old_getBoxHTML(provider, box_size, image_ext);
    this.img_path = old_img_path;
    return result;
  }
  return this.old_getBoxHTML(provider, box_size, image_ext);
}

// bugfix for upstream openid-selector issues:
// http://code.google.com/p/openid-selector/issues/detail?id=11
// http://code.google.com/p/openid-selector/issues/detail?id=12
openid.old_setOpenIdUrl = openid.setOpenIdUrl;
openid.setOpenIdUrl = function(url) {
  this.provider_url = null;
  $('#' + this.input_id).remove();
  this.old_setOpenIdUrl(url);
}

// bugfix for upstream openid-selector issue:
// http://code.google.com/p/openid-selector/issues/detail?id=10
providers_large.yahoo.url = 'http://me.yahoo.com/';
providers.yahoo.url = providers_large.yahoo.url;
providers_large.aol.url = 'http://openid.aol.com/{username}';
providers.aol.url = providers_large.aol.url;
providers_large.openid.url = '{username}';
providers.openid.url = providers_large.openid.url;

Drupal.behaviors.openid_selector = function (context) {
  if (!openid_selector.initialized) {
    openid.img_path = Drupal.settings.basePath + Drupal.settings.openid_selector.old_img_path;
    openid_selector.img_path = Drupal.settings.basePath + Drupal.settings.openid_selector.img_path;
    openid_selector.form_id = Drupal.settings.openid_selector.form_id;
    openid_selector.init();
    openid_selector.initialized = true;
  }
};

==> openid_selector-6.x-1.1.tar.gz: openid_selector/openid_selector.js <==
// $Id: openid_selector.js,v 1.3 2010/10/10 10:09:29 agerasika Exp $

var openid_selector = {
  img_path : null,
  form_id : null,
  init : function() {
    $('#edit-openid-identifier').val('')[0].id = 'old-edit-openid-identifier';
    $('#edit-openid-identifier-wrapper')
        .wrapInner('<div style="display: none;"/>')
        .prepend(
            '<div id="edit-openid-identifier"/> \
             <form action="javascript:openid_selector.inner_submit()" \
                id="openid_form" style="display: inline;"> \
                <div id="openid_choice"> \
                   <p>Click on your account provider:</p> \
                   <div id="openid_btns"/> \
                   <div id="openid_input_area" class="form-item"/> \
               </div> \
             </form>');
    openid.init("openid_identifier");
    $('#' + this.form_id).submit(this.outer_submit);
  },
  outer_submit : function() {
    openid.submit();
    if ($('#edit-openid-identifier-wrapper:visible').length > 0) {
      var val = $('#openid_identifier').val();
      $('#old-edit-openid-identifier').val(val);
    }
  },
  inner_submit : function() {
    this.outer_submit();
    var val = $('#old-edit-openid-identifier').val();
    if (val.indexOf("javascript:") === 0) {
      val = val.substr("javascript:".length);
      eval(val);
    } else
    $('#' + this.form_id).submit();
  }
};

// ui customization, overrides openid methods
openid.useInputBox = function(provider) {
  var is_block = openid_selector.form_id == 'user-login-form';
  var is_openid = provider['name'] == 'OpenID';
  $('#openid_input_area')
      .empty()
      .append(
          '<label for="openid_username">Log in using '
              + provider['name']
              + ':</label> \
           <input id="openid_username" type="text" style="'
              + (is_openid ? 'background:#FFF url('
                  + this.img_path
                  + 'openid-inputicon.gif) no-repeat scroll 0 50%; padding-left:18px;'
                  : '') + '" name="openid_username" value="'
              + (is_openid ? 'http://' : '') + '" maxlength="255" size="'
              + (is_block ? 15 : 58)
              + '" class="form-text"/> \
           <div class="description">'
              + provider['label'] + '</div>');
  $('#openid_username').focus();
}
providers_large.openid.label = '<a href="http://openid.net/">What is OpenID?</a>';
providers.openid.label = providers_large.openid.label;

openid.old_getBoxHTML = openid.getBoxHTML;
openid.getBoxHTML = function(provider, box_size, image_ext) {
  if (openid_selector.form_id == 'user-login-form' && box_size == 'large') {
    var old_img_path = this.img_path;
    this.img_path = openid_selector.img_path;
    var result = this.old_getBoxHTML(provider, 'small', '.ico.gif');
    this.img_path = old_img_path;
    return result;
  }
  return this.old_getBoxHTML(provider, box_size, image_ext);
}

providers_large.openid.url = '{username}';
providers.openid.url = providers_large.openid.url;

Drupal.behaviors.openid_selector = function (context) {
  if (!openid_selector.initialized) {
    if (!openid.setDemoMode) {
      alert('Website configuration error:\r\n' + 
          'Drupal OpenID Selector 1.1 requires Javascript OpenID Selector 1.1\r\n' +
          'Please contact website administrator.'); // and you have 1.0      
      return;
    }
    openid.img_path = Drupal.settings.basePath + Drupal.settings.openid_selector.old_img_path;
    openid_selector.img_path = Drupal.settings.basePath + Drupal.settings.openid_selector.img_path;
    openid_selector.form_id = Drupal.settings.openid_selector.form_id;
    openid_selector.init();
    openid_selector.initialized = true;
  }
};
